import * as tape from "tape";
import * as o from "../../../../dist/src/main";
import {pool} from "../../pool";

tape(__filename, async (t) => {
    const result = await pool.acquire(async (connection) => {
        await connection.rawQuery("DROP TEMPORARY TABLE IF EXISTS autoId");
        await connection.rawQuery(`
            CREATE TEMPORARY TABLE autoId (
                \`someId\` BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
                \`someValue\` BIGINT UNSIGNED NOT NULL,
                PRIMARY KEY(\`someId\`),
                CONSTRAINT blah UNIQUE (someValue)
            ) AUTO_INCREMENT = 18446744073709551612;
        `);
        await connection.rawQuery(`
            INSERT INTO autoId (someValue) VALUES (1);
        `);
        const autoId = o.table(
            "autoId",
            {
                someId : o.bigint(),
                someValue : o.bigint(),
            }
        ).setAutoIncrement(c => c.someId);
        const insertResult = await o.replaceInto(autoId)
            .values(
                {
                    someValue : BigInt(1),
                },
                {
                    someValue : BigInt(1),
                }
            )
            .execute(connection);
        t.deepEqual(
            insertResult,
            {
                fieldCount: 0,
                affectedRows: 4,
                insertId: 18446744073709551613n,
                serverStatus: 2,
                warningCount: 0,
                message: "&Records: 2  Duplicates: 2  Warnings: 0",
                protocol41: true,
                changedRows: 2,
                someId : 18446744073709551613n,
                insertedRowCount : 4,
            }
        );

        console.log(await connection.rawQuery(`
            SELECT LAST_INSERT_ID();
        `));
        return o.from(autoId)
            .select(c => [c])
            .fetchAll(connection);
    });
    t.deepEqual(result.length, 1);
    t.deepEqual(result[0].someId, 18446744073709551614n);
    t.deepEqual(result[0].someValue, 1n);

    t.end();
});
